import { Injectable, Optional, Inject, PLATFORM_ID, ɵɵdefineInjectable, ɵɵinject } from '@angular/core';
import { isPlatformBrowser } from '@angular/common';
import { __awaiter } from 'tslib';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const hasV8BreakIterator = (typeof Intl !== 'undefined' && ((/** @type {?} */ (Intl))).v8BreakIterator);
class Platform {
    /**
     * @param {?=} _platformId
     */
    constructor(_platformId) {
        this._platformId = _platformId;
    }
    // Browser check.
    /**
     * @return {?}
     */
    get isBrowser() {
        return this._platformId
            ? isPlatformBrowser(this._platformId)
            : typeof document === 'object' && !!document;
    }
    // Rendering engines.
    /**
     * @return {?}
     */
    get isTrident() {
        return this.isBrowser && /(msie|trident)/i.test(navigator.userAgent);
    }
    /**
     * @return {?}
     */
    get isBlink() {
        return this.isBrowser && (!!(((/** @type {?} */ (window))).chrome || hasV8BreakIterator) &&
            typeof CSS !== 'undefined' && !this.isEdge && !this.isTrident);
    }
    /**
     * @return {?}
     */
    get isWebkit() {
        return this.isBrowser && /AppleWebKit/i.test(navigator.userAgent)
            && !this.isBlink && !this.isEdge && !this.isTrident;
    }
    // Browsers.
    /**
     * @return {?}
     */
    get isChrome() {
        return this.isBrowser && /Google Inc./.test(navigator.vendor);
    }
    /**
     * @return {?}
     */
    get isEdge() {
        return this.isBrowser && /(edge)/i.test(navigator.userAgent);
    }
    /**
     * @return {?}
     */
    get isFirefox() {
        return this.isBrowser && /(firefox|minefield)/i.test(navigator.userAgent);
    }
    /**
     * @return {?}
     */
    get isSafari() {
        return this.isBrowser && /safari/i.test(navigator.userAgent) && this.isWebkit;
    }
    // Platforms.
    /**
     * @return {?}
     */
    get isIos() {
        return this.isBrowser && /iPad|iPhone|iPod/.test(navigator.userAgent) && !('MSStream' in window);
    }
    /**
     * @return {?}
     */
    get isAndroid() {
        return this.isBrowser && /android/i.test(navigator.userAgent) && !this.isTrident;
    }
    /**
     * @return {?}
     */
    get isDesktop() {
        return this.isBrowser && !(/(iPhone|iPod|iPad|Android|BlackBerry|IEMobile)/.test(navigator.userAgent));
    }
}
Platform.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
Platform.ctorParameters = () => [
    { type: Object, decorators: [{ type: Optional }, { type: Inject, args: [PLATFORM_ID,] }] }
];
/** @nocollapse */ Platform.ngInjectableDef = ɵɵdefineInjectable({ factory: function Platform_Factory() { return new Platform(ɵɵinject(PLATFORM_ID, 8)); }, token: Platform, providedIn: "root" });
if (false) {
    /**
     * @type {?}
     * @private
     */
    Platform.prototype._platformId;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ImageConverter {
    /**
     * @param {?} _platform
     */
    constructor(_platform) {
        this._platform = _platform;
        // Data.
        this._types = ['image/png', 'image/jpeg'];
        this.calculateOffsetAndDimensions = (/**
         * @param {?} image
         * @param {?} canvasWidth
         * @param {?} canvasHeight
         * @return {?}
         */
        (image, canvasWidth, canvasHeight) => {
            /** @type {?} */
            const originalWidth = image.width;
            /** @type {?} */
            const originalHeight = image.height;
            /** @type {?} */
            const widthRatio = canvasWidth / originalWidth;
            /** @type {?} */
            const heightRatio = canvasHeight / originalHeight;
            /** @type {?} */
            let width = 0;
            /** @type {?} */
            let height = 0;
            if (originalWidth > originalHeight) {
                height = originalHeight * heightRatio;
                width = (originalWidth / originalHeight) * height;
            }
            else {
                width = originalWidth * widthRatio;
                height = (originalHeight / originalWidth) * width;
            }
            /** @type {?} */
            let xOffset = 0;
            /** @type {?} */
            let yOffset = 0;
            if (canvasHeight === height) {
                xOffset = -((width - canvasWidth) / 2);
            }
            else if (canvasWidth === width) {
                yOffset = -((height - canvasHeight) / 2);
            }
            return { xOffset, yOffset, width, height };
        });
    }
    /**
     * @param {?} contents
     * @param {?=} options
     * @return {?}
     */
    toDataUri(contents, options = null) {
        return __awaiter(this, void 0, void 0, /** @this {!ImageConverter} */ function* () {
            // Check if the current platform is a browser.
            if (!this._platform.isBrowser) {
                return null;
            }
            // Get the image.
            /** @type {?} */
            const image = yield this.getImage(contents);
            // Get the canvas width and height.
            /** @type {?} */
            const canvasWidth = (options && options.width) || image.width;
            /** @type {?} */
            const canvasHeight = (options && options.height) || image.height;
            // Get the canvas and context.
            /** @type {?} */
            const canvas = document.createElement('canvas');
            /** @type {?} */
            const context = canvas.getContext('2d');
            canvas.width = canvasWidth;
            canvas.height = canvasHeight;
            // Check if dimensions where supplied, else create the image.
            if (!options) {
                // Draw the image.
                context.drawImage(image, 0, 0);
                // Convert the canvas to a data url.
                return canvas.toDataURL(this._types[0]);
            }
            // Get the dimensions and offsets.
            const { width, height, xOffset, yOffset } = this.calculateOffsetAndDimensions(image, canvasWidth, canvasHeight);
            // Draw the image.
            context.drawImage(image, 0, 0, image.width, image.height, xOffset, yOffset, width, height);
            // Convert the canvas to a data url.
            return canvas.toDataURL(this._types[0]);
        });
    }
    /**
     * @private
     * @param {?} contents
     * @return {?}
     */
    getImage(contents) {
        return __awaiter(this, void 0, void 0, /** @this {!ImageConverter} */ function* () {
            // If the contents is already an HTML image element just return it.
            if (contents instanceof HTMLImageElement) {
                return contents;
            }
            // If the contents is a file convert it to an HTML image element.
            if (contents instanceof File) {
                return this.fileToImage(contents);
            }
            // If the contents is a string convert it to an HTML image element.
            if (typeof contents === 'string') {
                return this.stringToImage(contents);
            }
        });
    }
    /**
     * @private
     * @param {?} file
     * @return {?}
     */
    fileToImage(file) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            // Check if the file matches an image.
            if (!this._types.includes(file.type)) {
                return reject('The selected file does not meet the required format.');
            }
            /** @type {?} */
            const fileReader = new FileReader();
            fileReader.readAsDataURL(file);
            fileReader.onloadend = (/**
             * @param {?} data
             * @return {?}
             */
            (data) => __awaiter(this, void 0, void 0, function* () {
                // Get the data URI.
                /** @type {?} */
                const dataUri = data.target['result'];
                // Convert the data URI to a image element.
                /** @type {?} */
                const image = yield this.stringToImage(dataUri);
                // Resolve the image.
                return resolve(image);
            }));
            fileReader.onerror = (/**
             * @param {?} error
             * @return {?}
             */
            error => reject(error));
        }));
    }
    /**
     * @private
     * @param {?} src
     * @return {?}
     */
    stringToImage(src) {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            /** @type {?} */
            const image = new Image();
            image.src = src;
            image.onload = (/**
             * @return {?}
             */
            () => resolve(image));
            image.onerror = (/**
             * @param {?} error
             * @return {?}
             */
            error => reject(error));
        }));
    }
}
ImageConverter.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
ImageConverter.ctorParameters = () => [
    { type: Platform }
];
/** @nocollapse */ ImageConverter.ngInjectableDef = ɵɵdefineInjectable({ factory: function ImageConverter_Factory() { return new ImageConverter(ɵɵinject(Platform)); }, token: ImageConverter, providedIn: "root" });
if (false) {
    /**
     * @type {?}
     * @private
     */
    ImageConverter.prototype._types;
    /**
     * @type {?}
     * @private
     */
    ImageConverter.prototype.calculateOffsetAndDimensions;
    /**
     * @type {?}
     * @private
     */
    ImageConverter.prototype._platform;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Languages {
    constructor() {
        this.getLanguages = (/**
         * @return {?}
         */
        () => {
            if (typeof navigator !== 'object') {
                return null;
            }
            /** @type {?} */
            let t = 'anguage';
            /** @type {?} */
            let n = navigator;
            /** @type {?} */
            let f = n['l' + t + 's'];
            /** @type {?} */
            const data = f && f.length ? f : (t = n['l' + t] ||
                n['browserL' + t] ||
                n['userL' + t]) ? [t] : t;
            return typeof data === 'string'
                ? data
                : data.join(';');
        });
    }
    /**
     * @return {?}
     */
    get all() {
        // Get the languages.
        /** @type {?} */
        const data = this.getLanguages();
        // Parse all languages by using a regex.
        /** @type {?} */
        const strings = (data || '')
            .match(/((([a-zA-Z]+(-[a-zA-Z0-9]+){0,2})|\*)(;q=[0-1](\.[0-9]+)?)?)*/g);
        // Get the content by parsing the strings.
        /** @type {?} */
        const content = strings.map((/**
         * @param {?} item
         * @return {?}
         */
        item => {
            if (!item) {
                return null;
            }
            /** @type {?} */
            const bits = item.split(';');
            /** @type {?} */
            const ietf = bits[0].split('-');
            /** @type {?} */
            const hasScript = ietf.length === 3;
            return {
                code: ietf[0],
                script: hasScript ? ietf[1] : null,
                region: hasScript ? ietf[2] : ietf[1],
                quality: bits[1] ? parseFloat(bits[1].split('=')[1]) : 1.0
            };
        }));
        // Filter out all the empty items
        // and sort them by the quality.
        return content
            .filter((/**
         * @param {?} item
         * @return {?}
         */
        item => !!item))
            .sort((/**
         * @param {?} a
         * @param {?} b
         * @return {?}
         */
        (a, b) => b.quality - a.quality));
    }
}
Languages.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */ Languages.ngInjectableDef = ɵɵdefineInjectable({ factory: function Languages_Factory() { return new Languages(); }, token: Languages, providedIn: "root" });
if (false) {
    /**
     * @type {?}
     * @private
     */
    Languages.prototype.getLanguages;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?} value
 * @return {?}
 */
function coerceBooleanProperty(value) {
    return value != null && `${value}` !== 'false';
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function CanDisable() { }
if (false) {
    /** @type {?} */
    CanDisable.prototype.disabled;
}
/**
 * @template T
 * @param {?} base
 * @return {?}
 */
function mixinDisabled(base) {
    return class extends base {
        /**
         * @param {...?} args
         */
        constructor(...args) {
            super(...args);
            this._disable = false;
        }
        /**
         * @return {?}
         */
        get disabled() {
            return this._disable;
        }
        /**
         * @param {?} value
         * @return {?}
         */
        set disabled(value) {
            this._disable = coerceBooleanProperty(value);
        }
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function CanLoad() { }
if (false) {
    /** @type {?} */
    CanLoad.prototype.loading;
}
/**
 * @template T
 * @param {?} base
 * @return {?}
 */
function mixinLoad(base) {
    return class extends base {
        /**
         * @param {...?} args
         */
        constructor(...args) {
            super(...args);
            this._loading = false;
        }
        /**
         * @return {?}
         */
        get loading() {
            return this._loading;
        }
        /**
         * @param {?} value
         * @return {?}
         */
        set loading(value) {
            this._loading = coerceBooleanProperty(value);
        }
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function HasError() { }
if (false) {
    /** @type {?} */
    HasError.prototype.error;
}
/**
 * @template T
 * @param {?} base
 * @return {?}
 */
function mixinError(base) {
    return class extends base {
        /**
         * @param {...?} args
         */
        constructor(...args) {
            super(...args);
            this._error = false;
        }
        /**
         * @return {?}
         */
        get error() {
            return this._error;
        }
        /**
         * @param {?} value
         * @return {?}
         */
        set error(value) {
            this._error = coerceBooleanProperty(value);
        }
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IsFocused() { }
if (false) {
    /** @type {?} */
    IsFocused.prototype.focused;
}
/**
 * @template T
 * @param {?} base
 * @return {?}
 */
function mixinFocused(base) {
    return class extends base {
        /**
         * @param {...?} args
         */
        constructor(...args) {
            super(...args);
            this._focused = false;
        }
        /**
         * @return {?}
         */
        get focused() {
            return this._focused;
        }
        /**
         * @param {?} value
         * @return {?}
         */
        set focused(value) {
            this._focused = coerceBooleanProperty(value);
        }
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IsGrouped() { }
if (false) {
    /** @type {?} */
    IsGrouped.prototype.grouped;
}
/**
 * @template T
 * @param {?} base
 * @return {?}
 */
function mixinGrouped(base) {
    return class extends base {
        /**
         * @param {...?} args
         */
        constructor(...args) {
            super(...args);
            this._grouped = false;
        }
        /**
         * @return {?}
         */
        get grouped() {
            return this._grouped;
        }
        /**
         * @param {?} value
         * @return {?}
         */
        set grouped(value) {
            this._grouped = coerceBooleanProperty(value);
        }
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IsReadonly() { }
if (false) {
    /** @type {?} */
    IsReadonly.prototype.readonly;
}
/**
 * @template T
 * @param {?} base
 * @return {?}
 */
function mixinReadonly(base) {
    return class extends base {
        /**
         * @param {...?} args
         */
        constructor(...args) {
            super(...args);
            this._readonly = false;
        }
        /**
         * @return {?}
         */
        get readonly() {
            return this._readonly;
        }
        /**
         * @param {?} value
         * @return {?}
         */
        set readonly(value) {
            this._readonly = coerceBooleanProperty(value);
        }
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IsRequired() { }
if (false) {
    /** @type {?} */
    IsRequired.prototype.required;
}
/**
 * @template T
 * @param {?} base
 * @return {?}
 */
function mixinRequired(base) {
    return class extends base {
        /**
         * @param {...?} args
         */
        constructor(...args) {
            super(...args);
            this._required = false;
        }
        /**
         * @return {?}
         */
        get required() {
            return this._required;
        }
        /**
         * @param {?} value
         * @return {?}
         */
        set required(value) {
            this._required = coerceBooleanProperty(value);
        }
    };
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const BbRegex = {
    email: /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/,
    fullNumber: /^\d*[1-9]\d*$/
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BbValidator {
    /**
     * @param {?} control
     * @return {?}
     */
    static email(control) {
        return BbRegex.email.test(control.value)
            ? null
            : { email: { valid: false } };
    }
    /**
     * @param {?} control
     * @return {?}
     */
    static fullNumber(control) {
        return BbRegex.fullNumber.test(control.value)
            ? null
            : { fullNumber: { valid: false } };
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { BbRegex, BbValidator, ImageConverter, Languages, Platform, coerceBooleanProperty, mixinDisabled, mixinError, mixinFocused, mixinGrouped, mixinLoad, mixinReadonly, mixinRequired };
//# sourceMappingURL=bravobit-bb-foundation.js.map
